/* Additional tests: */

/* The name of the package being compiled */
#define PACKAGE ""

/* The version of the package */
#define VERSION ""

/* Define if inline functions a la GCC are available.  */
#undef HAVE_INLINE

/* Define if inline functions a la GCC are available.  */
#undef HAVE_ALPHASORT_DECLARATION

/* Define if function attributes a la GCC 2.5 and higher are available.  */
#undef HAVE_GNUC25_ATTRIB

/* Define if constant functions a la GCC 2.5 and higher are available.  */
#undef HAVE_GNUC25_CONST

/* Define if nonreturning functions a la GCC 2.5 and higher are available.  */
#undef HAVE_GNUC25_NORETURN

/* Define if printf-format argument lists a la GCC are available.  */
#undef HAVE_GNUC25_PRINTFFORMAT

/* Set this to the canonical Debian architecture string for this CPU type. */
#undef ARCHITECTURE

/* Set this to 1 to build new archives by default. */
#define BUILDOLDPKGFORMAT 0

/* Set this string to append something to the version number. */
#define ARCHBINFMT ""

/* Define to the name of the distribution.  */
#undef PACKAGE

/* Define to 1 if NLS is requested.  */
#undef ENABLE_NLS

/* Define as 1 if you have catgets and don't want to use GNU gettext.  */
#undef HAVE_CATGETS

/* Define as 1 if you have gettext and don't want to use GNU gettext.  */
#undef HAVE_GETTEXT

/* Define if your locale.h file contains LC_MESSAGES.  */
#undef HAVE_LC_MESSAGES

/* Define as 1 if you have the stpcpy function.  */
#undef HAVE_STPCPY

/* Defined to $(localstatedir) dir location */
#undef LOCALSTATEDIR

/* Defined to the $(libdir) location */
#undef LLIBDIR

/* Define the ptrdiff_t type if your system doesn't have it */
#undef ptrdiff_t

/* Define if start-stop-daemon is compiled */
#undef USE_START_STOP_DAEMON

/* Define if you have the __va_copy macro */
#undef HAVE_VA_COPY
